@@ -33,7 +33,20 @@ create table numeric_types
 	mediumint_type mediumint null,
 	bigint_type bigint null,
 	decimal_type decimal null,
+	demical_2_type decimal(10,5) null,
 	float_type float null,
-	double_type double null
+	double_type double null,
+	bit_type bit null
+);
+
+create table if not exists date_types
+(
+	id int auto_increment
+		primary key,
+	date_type date null,
+	datetime_type datetime null,
+	timestamp_type timestamp null,
+	time_type time null,
+	year_type year null
 );
 
